#! /bin/sh
#  /etc/init.d/pi-led-daemon

### BEGIN INIT INFO
# Provides:          pi-led-daemon
# Required-Start:    $local_fs $remote_fs $syslog $network
# Required-Stop:     $local_fs $remote_fs $syslog $network
# Default-Start:     2 3 4 5
# Default-Stop:      0 1 6
# Short-Description: Starts the Pi-LED-Daemon service
# Description:       This file is used to start the daemon
#                    and should be placed in /etc/init.d
### END INIT INFO

# Author:   Raymund Fülöp <r[AT]ymund.de>
# Date:     30/06/2014

# hint for Eclipse users (like myself): this file must have UNIX line endings!

NAME="pi-led-daemon"
DESC="Pi-LED-Daemon service"

# The path to Jsvc
EXEC="/usr/bin/jsvc"

# The path to the folder containing the daemon .jar
FILE_PATH="/opt/$NAME"

# The path to the folder containing the java runtime
JAVA_HOME="$( readlink -f "$( which java )" | sed "s:bin/.*$::" )"

# Our classpath including our jar file and the Apache Commons Daemon library
CLASS_PATH="$FILE_PATH/lib/\*"

# The fully qualified name of the class to execute
CLASS="raymundo.pileddaemon.MainClass"

# Any command line arguments to be passed to the our Java Daemon implementations init() method 
ARGS=""

#The user to run the daemon as
USER="root"

# The file that will contain our process identification number (pid) for other scripts/programs that need to access it.
PID="/var/run/$NAME.pid"

# System.out writes to this file...
LOG_OUT="/var/log/$NAME.log"

# System.err writes to this file...
LOG_ERR="'&1'"

jsvc_exec()
{   
    cd $FILE_PATH
    COMMAND="$EXEC -home $JAVA_HOME -cp $CLASS_PATH -user $USER -outfile $LOG_OUT -errfile $LOG_ERR -pidfile $PID $1 $CLASS $ARGS"
    eval $COMMAND
}

case "$1" in
    start)  
        echo "Starting the $DESC..."        
        
        # Start the service
        jsvc_exec
        
        # echo "The $DESC has started."
    ;;
    stop)
        echo "Stopping the $DESC..."
        
        # Stop the service
        jsvc_exec "-stop"       
        
        echo "The $DESC has stopped."
    ;;
    restart)
        if [ -f "$PID" ]; then
            
            echo "Restarting the $DESC..."
            
            # Stop the service
            jsvc_exec "-stop"
            
            # Start the service
            jsvc_exec
            
            echo "The $DESC has restarted."
        else
            echo "Daemon not running, no action taken"
            exit 1
        fi
            ;;
    *)
    echo "Usage: /etc/init.d/$NAME {start|stop|restart}" >&2
    exit 3
    ;;
esac
